From 95e8f098909d9997a17f8ff0ecab524ac25713b2 Mon Sep 17 00:00:00 2001
From: PoorvaGaikar <pbgaikar_b21@el.vjti.ac.in>
Date: Sat, 9 Mar 2024 00:27:25 +0530
Subject: [PATCH v3] avfilter/f_select.c: add support for iw and ih constants

Fixes #10509
---
 doc/filters.texi       |  6 ++++++
 libavfilter/f_select.c | 14 +++++++++++++-
 2 files changed, 19 insertions(+), 1 deletion(-)

diff --git a/doc/filters.texi b/doc/filters.texi
index bfa8ccec8b..4b80378c79 100644
--- a/doc/filters.texi
+++ b/doc/filters.texi
@@ -30751,6 +30751,12 @@ missing.
 That basically means that an input frame is selected if its pts is within the
 interval set by the concat demuxer.
 
+@item iw @emph{(video only)}
+Represents the width of the input video frame
+
+@item ih @emph{(video only)}
+Represents the height of the input video frame
+
 @end table
 
 The default value of the select expression is "1".
diff --git a/libavfilter/f_select.c b/libavfilter/f_select.c
index 9b330a0673..e270ad8563 100644
--- a/libavfilter/f_select.c
+++ b/libavfilter/f_select.c
@@ -90,6 +90,9 @@ static const char *const var_names[] = {
 
     "concatdec_select",  ///< frame is within the interval set by the concat demuxer
 
+    "ih",                ///< ih: Represents the height of the input video frame.
+    "iw",                ///< iw: Represents the width of the input video frame.
+
     NULL
 };
 
@@ -144,6 +147,9 @@ enum var_name {
 
     VAR_CONCATDEC_SELECT,
 
+    VAR_IH,
+    VAR_IW,
+
     VAR_VARS_NB
 };
 
@@ -264,6 +270,9 @@ static int config_input(AVFilterLink *inlink)
     select->var_values[VAR_CONSUMED_SAMPLES_N] = NAN;
     select->var_values[VAR_SAMPLES_N]          = NAN;
 
+    select->var_values[VAR_IH] = NAN;
+    select->var_values[VAR_IW] = NAN;
+
     select->var_values[VAR_SAMPLE_RATE] =
         inlink->type == AVMEDIA_TYPE_AUDIO ? inlink->sample_rate : NAN;
 
@@ -357,6 +366,9 @@ FF_ENABLE_DEPRECATION_WARNINGS
         break;
 
     case AVMEDIA_TYPE_VIDEO:
+        select->var_values[VAR_IH] = frame->height;
+        select->var_values[VAR_IW] = frame->width;
+
         select->var_values[VAR_INTERLACE_TYPE] =
             !(frame->flags & AV_FRAME_FLAG_INTERLACED) ? INTERLACE_TYPE_P :
         (frame->flags & AV_FRAME_FLAG_TOP_FIELD_FIRST) ? INTERLACE_TYPE_T : INTERLACE_TYPE_B;
@@ -545,4 +557,4 @@ const AVFilter ff_vf_select = {
     FILTER_QUERY_FUNC(query_formats),
     .flags         = AVFILTER_FLAG_DYNAMIC_OUTPUTS | AVFILTER_FLAG_METADATA_ONLY,
 };
-#endif /* CONFIG_SELECT_FILTER */
+#endif /* CONFIG_SELECT_FILTER */
\ No newline at end of file
-- 
2.43.0.windows.1

